from __future__ import annotations

from dataclasses import dataclass, field
from typing import Optional

from .base import TelegramType
from .user import User


@dataclass
class MessageEntity(TelegramType):
    """
    This object represents one special entity in a text message.
    For example, hashtags, usernames, URLs, etc.
    Reference: https://core.telegram.org/bots/api#messageentity
    """

    type_: str
    """Type of the entity. Currently, can be “mention” (@username),
    “hashtag” (#hashtag), “cashtag” ($USD), “bot_command”
    (/start@jobs_bot), “url” (https://telegram.org), “email”
    (do-not-reply@telegram.org), “phone_number”
    (+1-212-555-0123), “bold” (bold text), “italic” (italic
    text), “underline” (underlined text), “strikethrough”
    (strikethrough text), “spoiler” (spoiler message), “code”
    (monowidth string), “pre” (monowidth block), “text_link”
    (for clickable text URLs), “text_mention” (for users without
    usernames)"""

    offset: int
    """Offset in UTF-16 code units to the start of the entity"""

    length: int
    """Length of the entity in UTF-16 code units"""

    url: Optional[str] = field(default=None)
    """Optional. For “text_link” only, url that will be opened
    after user taps on the text"""

    user: Optional[User] = field(default=None)
    """Optional. For “text_mention” only, the mentioned user"""

    language: Optional[str] = field(default=None)
    """Optional. For “pre” only, the programming language of the
    entity text"""
